CREATE TABLE IF NOT EXISTS IDN_CONFIG_TYPE (
      ID          VARCHAR(255)  NOT NULL,
      NAME        VARCHAR(255)  NOT NULL,
      DESCRIPTION VARCHAR(1023) NULL,

      PRIMARY KEY (ID),
      CONSTRAINT TYPE_NAME_CONSTRAINT UNIQUE (NAME)
);

INSERT INTO IDN_CONFIG_TYPE (ID, NAME, DESCRIPTION) VALUES
('8ec6dbf1-218a-49bf-bc34-0d2db52d151c', 'CORS_CONFIGURATION', 'A resource type to keep the tenant CORS configurations');

CREATE TABLE IF NOT EXISTS IDN_CONFIG_RESOURCE (
    ID            VARCHAR(255) NOT NULL,
    TENANT_ID     INT          NOT NULL,
    NAME          VARCHAR(255) NOT NULL,
    CREATED_TIME  TIMESTAMP    NOT NULL,
    LAST_MODIFIED TIMESTAMP    NOT NULL,
    HAS_FILE      BOOLEAN(1)   NOT NULL,
    HAS_ATTRIBUTE BOOLEAN(1)   NOT NULL,
    TYPE_ID       VARCHAR(255) NOT NULL,

    UNIQUE (NAME, TENANT_ID, TYPE_ID),
    PRIMARY KEY (ID)
);

ALTER TABLE IDN_CONFIG_RESOURCE
    ADD CONSTRAINT TYPE_ID_FOREIGN_CONSTRAINT FOREIGN KEY (TYPE_ID) REFERENCES IDN_CONFIG_TYPE (ID) ON DELETE CASCADE ON UPDATE CASCADE;

CREATE TABLE IF NOT EXISTS IDN_CONFIG_ATTRIBUTE (
    ID            VARCHAR(255)  NOT NULL,
    RESOURCE_ID   VARCHAR(255)  NOT NULL,
    ATTR_KEY      VARCHAR(1023) NOT NULL,
    ATTR_VALUE    VARCHAR(1023) NULL,

    PRIMARY KEY (ID),
    UNIQUE (RESOURCE_ID, ATTR_KEY, ATTR_VALUE)
);
ALTER TABLE IDN_CONFIG_ATTRIBUTE
    ADD CONSTRAINT RESOURCE_ID_ATTRIBUTE_FOREIGN_CONSTRAINT FOREIGN KEY (RESOURCE_ID) REFERENCES IDN_CONFIG_RESOURCE (ID) ON DELETE CASCADE ON UPDATE CASCADE;

CREATE TABLE IF NOT EXISTS IDN_CONFIG_FILE (
    ID        VARCHAR(255)    NOT NULL,
    VALUE     BLOB            NULL,
    NAME        VARCHAR (255) NULL,
    RESOURCE_ID VARCHAR(255)  NOT NULL,

    PRIMARY KEY (ID)
);
ALTER TABLE IDN_CONFIG_FILE
    ADD CONSTRAINT RESOURCE_ID_FILE_FOREIGN_CONSTRAINT FOREIGN KEY (RESOURCE_ID) REFERENCES IDN_CONFIG_RESOURCE (ID) ON DELETE CASCADE ON UPDATE CASCADE;

CREATE TABLE IF NOT EXISTS SP_APP (
    ID                INTEGER       NOT NULL AUTO_INCREMENT,
    TENANT_ID         INTEGER       NOT NULL,
    APP_NAME          VARCHAR (255) NOT NULL,
    UUID              CHAR(36),

    PRIMARY KEY (ID)
);

CREATE TABLE IF NOT EXISTS IDN_CORS_ORIGIN (
    ID        INT           NOT NULL AUTO_INCREMENT,
    TENANT_ID INT           NOT NULL,
    ORIGIN    VARCHAR(2048) NOT NULL,
    UUID      CHAR(36)      NOT NULL,

    PRIMARY KEY (ID),
    UNIQUE (TENANT_ID, ORIGIN),
    UNIQUE (UUID)
);

CREATE TABLE IF NOT EXISTS IDN_CORS_ASSOCIATION (
    IDN_CORS_ORIGIN_ID INT NOT NULL,
    SP_APP_ID          INT NOT NULL,

    PRIMARY KEY (IDN_CORS_ORIGIN_ID, SP_APP_ID),
    FOREIGN KEY (IDN_CORS_ORIGIN_ID) REFERENCES IDN_CORS_ORIGIN (ID) ON DELETE CASCADE
);

--Original schema has another foreign key with the SP_APP table.

CREATE INDEX IDX_IDN_CORS_ASSOCIATION_SP_APP_ID ON IDN_CORS_ASSOCIATION (SP_APP_ID);

CREATE INDEX IDX_IDN_CORS_ASSOCIATION_IDN_CORS_ORIGIN_ID ON IDN_CORS_ASSOCIATION (IDN_CORS_ORIGIN_ID);
